@@ -1,10 +1,7 @@
-# -*- encoding: utf-8 -*-
-from __future__ import unicode_literals
-
 from .toolbox import configure_djangoapp_plugin
 
 
-VERSION = (0, 15, 2)
+VERSION = (1, 2, 0)
 """Application version number tuple."""
 
 VERSION_STR = '.'.join(map(str, VERSION))
