@@ -1,5 +1,4 @@
-# -*- encoding: utf-8 -*-
-from __future__ import unicode_literals
+from typing import List
 
 import pytest
 
@@ -10,7 +9,7 @@ mail.outbox = []
 
 
 @pytest.fixture()
-def mail_outbox():
+def mail_outbox() -> List[mail.EmailMessage]:
     """Returns mail outbox: list of sent message objects.
 
     Example::
@@ -18,8 +17,6 @@ def mail_outbox():
         def test_this(mail_outbox):
             first_subject = mail_outbox[0].subject
 
-    :rtype: list[mail.EmailMessage]
-
     """
     yield mail.outbox
 
