@@ -6,11 +6,11 @@ from pytest_djangoapp.configuration import Configuration
 def test_configration(pytestconfig):
 
     settings = Configuration.get()
-    settings[Configuration._KEY_APP] = 'some'
+    settings[Configuration.KEY_APP] = 'some'
 
     assert Configuration.get_combined(pytestconfig)
 
-    settings[Configuration._KEY_APP] = ''
+    settings[Configuration.KEY_APP] = ''
     assert Configuration.get_combined(pytestconfig)
 
     def swap_dir(level):
