@@ -1,4 +1,10 @@
-from django.conf.urls import url
+try:
+    from django.urls import re_path
+    
+except ImportError:
+    from django.conf.urls import url as re_path
+
+    
 from django.http import HttpResponse
 
 from pytest_djangoapp.compat import get_urlpatterns
@@ -13,14 +19,14 @@ def index(request, some_id):
     if request.method == 'POST':
         return HttpResponse('json')
 
-    if request.is_ajax():
+    if request.META.get('HTTP_X_REQUESTED_WITH') == 'XMLHttpRequest':  # .headers in Django 2.2+
         return HttpResponse('ajaxed')
 
     from django.templatetags.static import static
-    return HttpResponse('%s | fine %s' % (some_id, static('blank.png')))
+    return HttpResponse(f"{some_id} | fine {static('blank.png')}")
 
 
 urlpatterns = get_urlpatterns([
-    url(r'^index/(?P<some_id>\d+)/$', index, name='index'),
-    url(r'^raiser/$', raise_exception, name='raiser'),
+    re_path(r'^index/(?P<some_id>\d+)/$', index, name='index'),
+    re_path(r'^raiser/$', raise_exception, name='raiser'),
 ])
